@@ -96,13 +96,13 @@ class Classification(FileUtils):
         '''
         import shutil        
         os.makedirs('modelfile', exist_ok=True)
-        os.makedirs(os.path.join(base_path, f'history_{model_id}'), exist_ok=True)
+        os.makedirs(os.path.join(base_path, f'dataset/history_{model_id}'), exist_ok=True)
         shutil.copyfile(os.path.join(base_path, f'dataset/{model_id}', 'classes.txt'), 
                         os.path.join(base_path, f'dataset/history_{model_id}', 'classes.txt'))
         shutil.copyfile(os.path.join(base_path, f'checkpoint/{model_id}/best_epoch_weights.pth'), 
-                        f'modelfile/{self.model_id}.pth')
+                        f'modelfile/{model_id}.pth')
         
         shutil.rmtree(os.path.join(base_path, f'dataset/{model_id}'))
-        shutil.rmtree(os.path.join(base_path, f'log/{model_id}'))
+        shutil.rmtree(os.path.join(base_path, f'log/loss_{model_id}'))
         shutil.rmtree(os.path.join(base_path, f'checkpoint/{model_id}'))
     
\ No newline at end of file
